@@ -1207,7 +1207,7 @@ hdf5_process_attribute (hid_t loc_id, const char *attrName, void *data)
   hid_t aid, sid, tid;
   H5T_class_t class;
   size_t tid_size;
-  char newname[strlen(attrName +1)];
+  char newname[strlen(attrName) +1];
   hdf5_global_attrcnt++;
   if (hdf5_global_verbosity > 1)
     Rprintf ("Processing attribute %d called %s\n",
@@ -1322,7 +1322,7 @@ hdf5_process_attribute (hid_t loc_id, const char *attrName, void *data)
 	  if (H5Aread (aid, memtid, buf) < 0)
 	    errorcall (ainfo->call, "unable to read attribute `%s'", attrName);
 	  if (hdf5_global_verbosity > 2) 
-	    Rprintf ("string length of new name =%d\n",strlen(attrName+1));
+	    Rprintf ("string length of new name =%d\n",strlen(attrName)+1);
 	  strcpy(newname,attrName);
 	  if (hdf5_global_nametidy)
             {
